import processing.serial.*;

Serial myPort;   // The serial port
int servoPos;    // Variable to store the servo position
float displayPos; // Variable to store the displayed position

void setup() {
  // Set the window size
  size(800, 600);
  
  // List all the available serial ports
  println(Serial.list());
  
  // Open the port you are using at the same speed as the Arduino
  String portName = Serial.list()[1];  // Replace with the correct index
  myPort = new Serial(this, portName, 9600);
  
  // Set initial background color
  background(255);
  
  // Initialize display position
  displayPos = 0;
}

void draw() {
  // Read the serial buffer
  while (myPort.available() > 0) {
    String inString = myPort.readStringUntil('\n');
    if (inString != null) {
      inString = trim(inString);
      servoPos = int(inString);
    }
  }
  
  // Smoothly transition the displayed position
  displayPos = lerp(displayPos, servoPos, 0.1);
  
  // Clear the background with a gradient
  for (int i = 0; i < height; i++) {
    stroke(map(i, 0, height, 255, 200), map(i, 0, height, 255, 230), map(i, 0, height, 255, 255));
    line(0, i, width, i);
  }
  
  // Map the servo position to a graphical position
  float x = map(displayPos, 0, 180, 100, width - 100);
  
  // Draw a fancy circle for the servo position
  noStroke();
  fill(50, 150, 255, 150);
  ellipse(x, height / 2, 100, 100);  // Outer circle
  fill(50, 150, 255);
  ellipse(x, height / 2, 80, 80);    // Inner circle
  
  // Draw the position value with a shadow
  textSize(32);
  textAlign(CENTER);
  fill(50, 150, 255, 150);
  text("Servo Position: " + nf(displayPos, 1, 2), width / 2 + 2, height - 32 + 2);
  fill(0);
  text("Servo Position: " + nf(displayPos, 1, 2), width / 2, height - 32);
}
